@@ -210,6 +210,12 @@ class TestDerivs(unittest.TestCase):
 
         self.assertEqual(len(conn['t1_1'].list()), 5)
 
+        conn['t1_2'] = conn['t1'].by('col1').filter(lambda rs: len(rs) > 1)
+
+        self.assertEqual(len(conn['t1_2'].list()), 5)
+
+    
+
     def test_update(self):
         conn = Conn(self.dbfile)
         conn['t1'] = table1
